guix_mirror_bot pushed a commit to branch ruby-team
in repository guix.

commit 95b075b855281c5a87faa1caf981c2aa46ab9bf4
Author: Andreas Enge <[email protected]>
AuthorDate: Tue Aug 18 15:28:06 2026 +0200

    gnu: gnupg: Simplify gexp logic.
    
    * gnu/packages/gnupg.scm (gnupg)[arguments]<#:configure-flags>: Use pure
    gexp instead of mixture with standard (un-)quotes.
    
    Merges: guix/guix!10645
---
 gnu/packages/gnupg.scm | 50 ++++++++++++++++++++++++--------------------------
 1 file changed, 24 insertions(+), 26 deletions(-)

diff --git a/gnu/packages/gnupg.scm b/gnu/packages/gnupg.scm
index c4a7edc90f..da068596e4 100644
--- a/gnu/packages/gnupg.scm
+++ b/gnu/packages/gnupg.scm
@@ -364,32 +364,30 @@ compatible to GNU Pth.")
     (arguments
      (list
       #:configure-flags
-      ;; Always use quasiquote on the next core-updates cycle.
-      #~(#$(if (%current-target-system)
-               #~quasiquote
-               #~quote)
-         (#$@(if (%current-target-system)
-                 #~(,(string-append
-                      "--with-libgpg-error-prefix="
-                      #$(this-package-input "libgpg-error"))
-                    ,(string-append
-                      "--with-libgcrypt-prefix="
-                      #$(this-package-input "libgcrypt"))
-                    ,(string-append
-                      "--with-libassuan-prefix="
-                      #$(this-package-input "libassuan"))
-                    ,(string-append
-                      "--with-ksba-prefix="
-                      #$(this-package-input "libksba"))
-                    ,(string-append
-                      "--with-npth-prefix="
-                      #$(this-package-input "npth")))
-                 #~())
-          ;; Otherwise, the test suite looks for the `gpg`
-          ;; executable in its installation directory in
-          ;; /gnu/store before it has been installed.
-          "--enable-gnupg-builddir-envvar"
-          "--enable-all-tests"))
+      #~(list
+           ;; Otherwise, the test suite looks for the `gpg`
+           ;; executable in its installation directory in
+           ;; /gnu/store before it has been installed.
+           "--enable-gnupg-builddir-envvar"
+           "--enable-all-tests"
+           #$@(if (%current-target-system)
+                  (list
+                    #~(string-append
+                        "--with-libgpg-error-prefix="
+                        #$(this-package-input "libgpg-error"))
+                    #~(string-append
+                        "--with-libgcrypt-prefix="
+                        #$(this-package-input "libgcrypt"))
+                    #~(string-append
+                        "--with-libassuan-prefix="
+                        #$(this-package-input "libassuan"))
+                    #~(string-append
+                        "--with-ksba-prefix="
+                        #$(this-package-input "libksba"))
+                    #~(string-append
+                        "--with-npth-prefix="
+                        #$(this-package-input "npth")))
+                  '()))
       #:phases
       #~(modify-phases %standard-phases
           (add-before 'configure 'patch-paths

Reply via email to